@@ -2,7 +2,10 @@
 import io
 import sys
 import unittest
-import mock
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 import pytest
 import requests
 from requests_toolbelt.multipart.decoder import BodyPart
@@ -128,7 +131,7 @@ class TestMultipartDecoder(unittest.TestCase):
     def test_header_of_parts(self):
         def parts_header_equal(part, sample):
             return part.headers[b'Content-Disposition'] == encode_with(
-                'form-data; name="{0}"'.format(sample[0]), 'utf-8'
+                'form-data; name="{}"'.format(sample[0]), 'utf-8'
             )
 
         parts_iter = zip(self.decoded_1.parts, self.sample_1)
@@ -188,4 +191,3 @@ class TestMultipartDecoder(unittest.TestCase):
         assert decoder_2.parts[0].headers[b'Header-1'] == b'Header-Value-1'
         assert len(decoder_2.parts[1].headers) == 0
         assert decoder_2.parts[1].content == b'Body 2, Line 1'
-
