@@ -2,7 +2,10 @@
 import unittest
 import sys
 
-from mock import patch
+try:
+    from unittest.mock import patch
+except ImportError:
+    from mock import patch
 import pytest
 
 from requests_toolbelt.utils import user_agent as ua
